summaryrefslogtreecommitdiff
path: root/Master/texmf-dist/scripts
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2016-05-08 23:08:36 +0000
committerKarl Berry <karl@freefriends.org>2016-05-08 23:08:36 +0000
commit832ec096de086b522aac5080489e36c59a75c848 (patch)
tree2d35a4aff62f509d2a28a7f48d60c6e7038a9239 /Master/texmf-dist/scripts
parent5d2aa452c6463d16a4f0f06c1b46bd2d6c124622 (diff)
tlmgr key remove, rather than delete; doc
git-svn-id: svn://tug.org/texlive/trunk@40964 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/texmf-dist/scripts')
-rwxr-xr-xMaster/texmf-dist/scripts/texlive/tlmgr.pl54
1 files changed, 23 insertions, 31 deletions
diff --git a/Master/texmf-dist/scripts/texlive/tlmgr.pl b/Master/texmf-dist/scripts/texlive/tlmgr.pl
index 0487fc95b1a..f1d5315fbd1 100755
--- a/Master/texmf-dist/scripts/texlive/tlmgr.pl
+++ b/Master/texmf-dist/scripts/texlive/tlmgr.pl
@@ -2453,7 +2453,7 @@ sub action_update {
# we require:
# if no --list is given: either --self or --all or <pkgs>
# if --list is given: nothing
# other options just change the behaviour
if (!($opts{"list"} || @ARGV || $opts{"all"} || $opts{"self"})) {
tlwarn("$prg update: specify --list, --all, --self, or a list of package names.\n");
return ($F_ERROR);
@@ -5624,22 +5624,20 @@ sub texconfig_conf_mimic {
#
# tlmgr key list
# tlmgr key add <filename>
-# tlmgr key delete <keyid>
+# tlmgr key remove <keyid>
sub action_key {
my $arg = shift @ARGV;
-
-
if (!defined($arg)) {
tlwarn("missing arguments to action `key'\n");
return $F_ERROR;
}
$arg = lc($arg);
- if ($arg =~ /^(add|delete|list)$/) {
+ if ($arg =~ /^(add|remove|list)$/) {
handle_gpg_config_settings();
if (!$::gpg) {
- tlwarn("gnupg is not found or setup, cannot continue with action `key'\n");
+ tlwarn("gnupg is not found or not set up, cannot continue with action `key'\n");
return $F_ERROR;
}
chomp (my $TEXMFSYSCONFIG = `kpsewhich -var-value=TEXMFSYSCONFIG`);
@@ -5648,15 +5646,15 @@ sub action_key {
debug("running $::gpg --list-keys\n");
system("$::gpg --list-keys");
return $F_OK;
- } elsif ($arg eq 'delete') {
+ } elsif ($arg eq 'remove') {
my $what = shift @ARGV;
if (!$what) {
- tlwarn("missing argument to `key add'\n");
+ tlwarn("missing argument to `key remove'\n");
return $F_ERROR;
}
- # we need to make sure that $local_keyring is existent!
+ # we need to make sure that $local_keyring exists.
if (! -r $local_keyring) {
- tlwarn("no local keyring available, cannot delete anything!\n");
+ tlwarn("no local keyring available, cannot remove!\n");
return $F_ERROR;
}
debug("running: $::gpg --primary-keyring repository-keys.gpg --delete-key $what\n");
@@ -7116,28 +7114,22 @@ C<--reinstall>, as in (using the C<fontspec> package as the example):
=back
-=head2 key I<args>
+=head2 key list|add I<file>|remove I<keyid>
=over 4
-=item B<key list>
-
-=item B<key add I<what>>
-
-=item B<key remove I<keyid>>
-
-The action C<key> allows listing, adding and removing additional keys
-to the set of trusted keys, that is those that are used to verify the
-TeX Live databases.
+The action C<key> allows listing, adding and removing additional GPG
+keys to the set of trusted keys, that is, those that are used to verify
+the TeX Live databases.
-With the C<list> argument lists all keys.
+With the C<list> argument, C<key> lists all keys.
The C<add> argument requires another argument, either a filename or
C<-> for stdin, from which the key is added. The key is added to the
-local keyring C<GNUPGHOME/repository-keys.gpg>, which normally is
+local keyring C<GNUPGHOME/repository-keys.gpg>, which is normally)
C<tlpkg/gpg/repository-keys.gpg>.
-The C<delete> argument requires a key id and removes the requested id
+The C<remove> argument requires a key id and removes the requested id
from the local keyring.
=head2 option
@@ -7228,7 +7220,7 @@ The C<sys_bin>, C<sys_man>, and C<sys_info> options are used on
Unix-like systems to control the generation of links for executables,
info files and man pages. See the C<path> action for details.
-The last three options control behaviour on Windows installations. If
+The last three options control behavior on Windows installations. If
C<desktop_integration> is set, then some packages will install items in
a sub-folder of the Start menu for C<tlmgr gui>, documentation, etc. If
C<fileassocs> is set, Windows file associations are made (see also the
@@ -7834,14 +7826,14 @@ our context.) C<no-checksums> also avoids the warning.
=head1 CRYPTOGRAPHIC VERIFICATION
-If a working GnuPG binary (C<gpg>) is found (see below for the search
+If a working GnuPG binary (C<gpg>) is found (see below for search
method), by default verification of downloaded files is performed. This
can be suppressed by specifying C<--no-verify-downloads> on the command
-line, or adding an entry C<verify-downloads = 0> to a tlmgr config file
-(described in L<CONFIGURATION FILE FOR TLMGR>). On the other hand,
-it is possible to B<require> verification by either specifying
-C<--require-verification> on the command line, or adding an entry
-C<require-verification = 1> to a tlmgr config file.
+line, or adding an entry C<verify-downloads = 0> to a C<tlmgr> config
+file (described in L<CONFIGURATION FILE FOR TLMGR>). On the other hand,
+it is possible to I<require> verification by specifying
+C<--require-verification> on the command line, or by adding an entry
+C<require-verification = 1> to a C<tlmgr> config file.
Verification is performed as follows: For each C<texlive.tlpdb> loaded
for a repository, the respective checksum C<texlive.tlpdb.sha512> is
@@ -7865,7 +7857,7 @@ variable C<TL_GNUPG> is set, it is tested and used; otherwise C<gpg> is
checked; finally C<gpg2> is checked.
Further adaptation of the C<gpg> invocation can be made using the two
-enviroment variables C<TL_GNUPGHOME>, which is passed to C<gpg> as the
+environment variables C<TL_GNUPGHOME>, which is passed to C<gpg> as the
value for C<--homedir>, and C<TL_GNUPGARGS>, which replaces the default
arguments C<--no-secmem-warning --no-permission-warning>.
@@ -2453,7 +2453,7 @@ sub action_update {
# if no --list is given: either --self or --all or <pkgs>
# if --list is given: nothing
- # other options just change the behaviour
+ # other options just change the behavior
if (!($opts{"list"} || @ARGV || $opts{"all"} || $opts{"self"})) {
tlwarn("$prg update: specify --list, --all, --self, or a list of package names.\n");